@@ -13,7 +13,9 @@ geom_icon <- function(mapping = NULL, data = NULL, inherit.aes = TRUE,
 
 icon <- function(id) {
     ## paste0('https://raw.githubusercontent.com/ionic-team/ionicons/master/src/svg/', id, '.svg')
-    paste0('https://ionicons.com/ionicons/svg/', id, '.svg')
+    url <- paste0('https://ionicons.com/ionicons/svg/', id, '.svg')
+
+    check_url(url)
 }
 
 ##' list available icon
